==> patternfly-java-core-0.2.4-sources.jar: org/patternfly/style/VariableNames.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.style;

import org.patternfly.core.Version;

class VariableNames {

    static String globalName(String firstElement, String... otherElements) {
        StringBuilder builder = new StringBuilder();
        if (firstElement != null && !firstElement.isEmpty()) {
            builder.append("--pf-").append(Version.PATTERN_FLY_MAJOR_VERSION).append("-global--").append(firstElement);
            if (otherElements != null && otherElements.length != 0) {
                builder.append("--");
                for (int i = 0; i < otherElements.length; i++) {
                    builder.append(otherElements[i]);
                    if (i < otherElements.length - 1) {
                        builder.append("--");
                    }
                }
            }
        }
        return builder.toString();
    }

    static String componentName(String component, String... elements) {
        StringBuilder builder = new StringBuilder();
        if (component != null && component.startsWith("pf-" + Version.PATTERN_FLY_MAJOR_VERSION + "-")) {
            builder.append("--").append(component);
            if (elements != null && elements.length != 0) {
                builder.append("--");
                for (int i = 0; i < elements.length; i++) {
                    builder.append(elements[i]);
                    if (i < elements.length - 1) {
                        builder.append("--");
                    }
                }
            }
        }
        return builder.toString();
    }
}

==> patternfly-java-core-0.2.9-sources.jar: org/patternfly/style/VariableNames.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.style;

import org.patternfly.core.Version;

class VariableNames {

    static String globalName(String firstElement, String... otherElements) {
        StringBuilder builder = new StringBuilder();
        if (firstElement != null && !firstElement.isEmpty()) {
            builder.append("--pf-").append(Version.PATTERN_FLY_MAJOR_VERSION).append("-global--").append(firstElement);
            if (otherElements != null && otherElements.length != 0) {
                builder.append("--");
                for (int i = 0; i < otherElements.length; i++) {
                    builder.append(otherElements[i]);
                    if (i < otherElements.length - 1) {
                        builder.append("--");
                    }
                }
            }
        }
        return builder.toString();
    }

    static String utilName(String firstElement, String... otherElements) {
        StringBuilder builder = new StringBuilder();
        if (firstElement != null && !firstElement.isEmpty()) {
            builder.append("--pf-").append(Version.PATTERN_FLY_MAJOR_VERSION).append("-u-").append(firstElement);
            if (otherElements != null && otherElements.length != 0) {
                builder.append("--");
                for (int i = 0; i < otherElements.length; i++) {
                    builder.append(otherElements[i]);
                    if (i < otherElements.length - 1) {
                        builder.append("--");
                    }
                }
            }
        }
        return builder.toString();
    }

    static String componentName(String component, String... elements) {
        StringBuilder builder = new StringBuilder();
        if (component != null && component.startsWith("pf-" + Version.PATTERN_FLY_MAJOR_VERSION + "-")) {
            builder.append("--").append(component);
            if (elements != null && elements.length != 0) {
                builder.append("--");
                for (int i = 0; i < elements.length; i++) {
                    builder.append(elements[i]);
                    if (i < elements.length - 1) {
                        builder.append("--");
                    }
                }
            }
        }
        return builder.toString();
    }
}
